![beastiary logo](docs/images/logo.png)


[![PyPi](https://img.shields.io/pypi/v/beastiary.svg)](https://pypi.org/project/beastiary/)
[![tests](https://github.com/Wytamma/beastiary/actions/workflows/test.yml/badge.svg)](https://github.com/Wytamma/beastiary/actions/workflows/test.yml)
[![cov](https://codecov.io/gh/Wytamma/beastiary/branch/master/graph/badge.svg)](https://codecov.io/gh/Wytamma/beastiary)
[![docs](https://github.com/Wytamma/beastiary/actions/workflows/docs.yml/badge.svg)](https://beastiary.wytamma.com/)

This is a replacement for tracer. It's feature feature is the real time aspect. Secondly it's modern looking. 3rd it has improved features. 


## CLI
Launch the app
Can point to log file to autostart watcher

## Webapp 
Vue
Plotly

## Web API
FastAPI that sends data to and from DB and servers the webapp
Can start file watchers

## Watcher 
Python class that watches files and updates DB with changes.


## BD (MEMORY)
Protected by the CRUD


## distribution 
CLI vs app (just launches web browser)
https://docs.python-guide.org/shipping/freezing/
